#! /bin/sh
SETUP_PRODUCTNAME="picasa"
SETUP_PRODUCTVER="1.0"
SETUP_COMPONENTNAME="Default"
SETUP_COMPONENTVER="1.0"
SETUP_INSTALLPATH="/opt/picasa/"
SETUP_SYMLINKSPATH="/usr/local/bin"
SETUP_CDROMPATH=""
SETUP_DISTRO="slackware"
SETUP_OPTIONTAGS="icons detector"
export SETUP_PRODUCTNAME SETUP_PRODUCTVER SETUP_COMPONENTNAME SETUP_COMPONENTVER
export SETUP_INSTALLPATH SETUP_SYMLINKSPATH SETUP_CDROMPATH SETUP_DISTRO SETUP_OPTIONTAGS
#!/bin/bash
# postuninstall.sh - script to run as we finish up removing Picasa

#include ../util/icons.sh.include
#!/bin/bash
#---------------------------------------------
#   icons.sh
#       Copyright 2006 by Google
#
#   Utility script to create icons on a Linux desktop.
#   Works on most XDG compliant Linux systems; does
#   not work everywhere.
#
#   Refer to the usage() function below for usage.
#---------------------------------------------

usage()
{
    echo Usage:
    echo  $0 "[--root|--user] [--create desktop|--delete desktop]"
    echo "Where --user (install only for the user file) is the default."
    echo One of --create or --delete must be specified.
    echo With --create, the file specified must exist and be a valid XDG .desktop file
    echo With --delete, the file must be a pattern that will exist
}



icons()
{
    xdg_user_dir=$XDG_DATA_HOME
    [ -n "$xdg_user_dir" ] || xdg_user_dir=$HOME/.local/share

    xdg_data_dirs=$XDG_DATA_DIRS
    [ -n "$xdg_data_dirs" ] || xdg_data_dirs=/usr/local/share/:/usr/share/
    for x in `echo $xdg_data_dirs | sed 's/:/ /g'` ; do
        if [ -w $x/applications/ ] ; then
            xdg_global_dir=$x
            break
        fi
    done
    [ -w $xdg_global_dir ] || xdg_global_dir=

    kde_user_dir=$HOME/.kde/share/applnk
    kde_global_dir=/usr/share/applnk
    [ -w $kde_global_dir ] || kde_global_dir=

    gnome_user_dir=$HOME/.gnome/apps
    gnome_global_dir=/usr/share/gnome/apps
    [ -w $gnome_global_dir ] || gnome_global_dir=

    mode=user
    action=
    while [ $# -gt 0 ] ; do
        parm=$1
        shift

        case $parm in
          --create)
            if [ ! -f "$1" ] ; then
                echo Error:  You must specify a valid desktop file as a paramter to --create.
                return 1
            fi
            if [ -n "$action" ] ; then
                echo Error:  You must specify only one of --create or --delete
                return 1
            fi

            action=create
            desktop_file=$1
            shift
            ;;

          --delete)
            if [ -z "$1" ] ; then
                echo Error:  You must specify a desktop file name as a paramter to --delete.
                return 1
            fi
            if [ -n "$action" ] ; then
                echo Error:  You must specify only one of --create or --delete
                return 1
            fi
            action=delete
            desktop_file=$1
            shift
            ;;

          --user)
            mode=user
            ;;

          --root)
            mode=root
            ;;

          *)
            echo "$parm:  Invalid parameter/option"
            usage
            return 2
            ;;
        esac
    done

    if [ -z "$action" ] ; then
        usage
        return 2
    fi

    desktop_dir=
    if [ "$mode" = "user" ] ; then
        xdg_dir=$xdg_user_dir/applications
        kde_dir=$kde_user_dir
        gnome_dir=$gnome_user_dir
        my_umask=077
        if [ -d $HOME/Desktop -a -w $HOME/Desktop ] ; then
            desktop_dir=$HOME/Desktop
        fi
    else
        xdg_dir=$xdg_global_dir/applications
        kde_dir=$kde_global_dir
        gnome_dir=$gnome_global_dir
        my_umask=022
    fi

    #echo "[xdg|$xdg_user_dir|$xdg_global_dir]"
    #echo "[kde|$kde_user_dir|$kde_global_dir]"
    #echo "[gnome|$gnome_user_dir|$gnome_global_dir]"

    #echo "[using|$xdg_dir|$kde_dir|$gnome_dir]"


    case $action in 
        create)
            save_umask=`umask`
            umask $my_umask
            basefile=`basename $desktop_file`

            for x in $xdg_dir $kde_dir $gnome_dir $desktop_dir ; do
                mkdir -p $x
                cp $desktop_file $x
            done

            if [ -f $kde_dir/$basefile ] ; then
                echo "OnlyShowIn=Old;" >> $kde_dir/$basefile
            fi

            if [ -f $gnome_dir/$basefile ] ; then
                echo "OnlyShowIn=Old;" >> $gnome_dir/$basefile
            fi

            umask $save_umask
            ;;

        delete)
            for x in $xdg_dir $kde_dir $gnome_dir $desktop_dir ; do
                rm -f $x/$desktop_file
            done
            
            ;;
    esac

    return 0

}

#include ../util/setpicasascreensaver.sh.include
#!/bin/bash
#       setpicasascreensaver
#   Script to set up Picasa as a screen saver
#
#   FIXME - This script is imperfect, and has many flaws, amongst which are:
#           1.  If there are multiple user installs on a system,
#               they will not coexist peacefully.  Each will clobber
#               the other in turn.  A root install on that system
#               should work okay.
#           2.  The set option really only works the first time.
#               If the user changes screen savers, and notably
#               makes Picasa not be the 0th in the list, then
#               this won't work.
#           3.  Unset only sorta kinda works.  The user will likely
#               have to manually fix their screen saver after removing
#               Picasa
#           4.  There is no support for the new fancy dancy Gnome screen saver
#
#

usage()
{
    echo Usage:
    echo  $0 action
    echo "Where action is one of:"
    echo "  install         -   Install showpicasascreensaver to /usr/[X11R6]/lib/xscreensaver"
    echo "  remove          -   Remove showpicasascreensaver from /usr/[X11R6]/lib/xscreensaver"
    echo "  set             -   Setup a screen saver for the current user, performing the"
    echo "                      install step if it can be done easily, and there is no"
    echo "                      showpicasascreensaver already"
    echo "  unset           -   Cleanup user specific screen saver settings at picasa removal"
}


# Locate where our root is installed by looking for the directory
# where this this script is located, unwinding symlinks on the way
locate_pic_root()
{
    if [ -z "$PIC_ROOT" ]
    then
        argv0=`which "$0"`
        [ -z "$argv0" ] && argv0="$0"
        echo "$argv0" | egrep "^/" >/dev/null
        if [ $? -ne 0 ]
        then
            argv0="`pwd`/$argv0"
        fi
        dir=`dirname "$argv0"`
        while [ ! -x "$dir/../wine/bin/wine" ]
        do
            [ ! -h "$argv0" ] && break
            argv0=`ls -l "$argv0" | sed -e 's/^.*-> //'`
            echo "$argv0" | egrep "^/" >/dev/null
            if [ $? -ne 0 ]
            then
                argv0="$dir/$argv0"
            fi
            dir=`dirname "$argv0"`
        done
        dir=`echo "$dir" | sed -e 's%\(/\.\)*$%%' -e 's%\(/\./\(\./\)*\)%/%'`
        PIC_ROOT="$dir/.."
        PIC_BINDIR="$dir"
    fi
    if [ ! -x "$PIC_ROOT/wine/bin/wine" ]
    then
        if [ "$1" = "--no-fail" ]
        then
            PIC_ROOT=""
            return 1
        fi
        #echo "`basename \"$0\"`:error: could not find wine/bin/wine in '$PIC_ROOT'" >&2
        return 1
    fi
    # Make sure it's exported
    export PIC_ROOT
    export PIC_BINDIR
    return 0
}


setpicasascreensaver()
{

    action=
    while [ $# -gt 0 ] ; do
        parm=$1
        shift

        case $parm in
          install | remove | set | unset)
            action=$parm
            shift
            ;;

          *)
            echo "$parm:  Invalid parameter/option"
            usage
            return 2
            ;;
        esac
    done

    if [ -z "$action" ] ; then
        usage
        return 2
    fi


    locate_pic_root

    # If /usr/[X11R6/]lib/screensaver doesn't have showpicasascreensaver, add it there, with XXXsu if need be
    for x in /usr/lib/xscreensaver /usr/X11R6/lib/xscreensaver ; do
        if [ -d "$x" ] ; then
            screen_dir="$x"
            break;
        fi
    done

    # Handle remove actions
    if [ "$action" = "remove" ] ; then
        for x in /usr/lib/xscreensaver /usr/X11R6/lib/xscreensaver ; do
            if [ -f "$x/showpicasascreensaver" ] ; then
                rm -f "$x/showpicasascreensaver"
                break;
            fi
        done

        return 0
    fi

    # Handle install actions
    if [ "$action" = "install" ] ; then
        if [ -d "$screen_dir" ] ; then
            if [ -h "$screen_dir/showpicasascreensaver" ] ; then
                rm -f "$screen_dir/showpicasascreensaver"  
            fi
            ln -s $PIC_BINDIR/showpicasascreensaver "$screen_dir/"
        fi

        return 0
    fi


    # Handle unset actions
    if [ "$action" = "unset" ] ; then
        rm -f ~/.kde/share/applnk/System/ScreenSavers/picasascr.desktop 
        return 0
    fi


    ###
    #   From here on, everything is presumed to be a set option
    #       which is meant to be done just for this user
    ###

    if [ -d "$screen_dir" ] ; then
        if [ ! -f "$screen_dir/showpicasascreensaver" ] ; then
            if [ -n "$KDE_FULL_SESSION" -o "$GDMSESSION" = "KDE" ] ; then
                kdesu -c "ln -s $PIC_BINDIR/showpicasascreensaver $screen_dir/"
            else
                export PATH=$PATH:$PIC_BINDIR
                xsu -u root -c "ln -s $PIC_BINDIR/showpicasascreensaver $screen_dir/"
            fi
        fi
    fi

    # Next, set up ~/.xscreensaver correctly

    if [ ! -f ~/.xscreensaver ] ; then
        echo 'selected: 0 ' >~/.xscreensaver
        echo 'programs: "Picasa Screensaver" showpicasascreensaver' >>~/.xscreensaver
    else
        grep -iq picasa ~/.xscreensaver
        if [ $? -gt 0 ] ; then
            cat ~/.xscreensaver |
              sed 's/^\programs:.*\\$/\0\
                "Picasa ScreenSaver" showpicasascreensaver \\n\\/g' | \
              sed 's/^\selected:.*$/selected:    0/' > ~/.xscreensaver.picasa
        else
            cat ~/.xscreensaver |
              sed 's/^\selected:.*$/selected:    0/' > ~/.xscreensaver.picasa
        fi

        if [ ! -f ~/.xscreensaver.before.picasa ] ; then
            if [ -f ~/.xscreensaver ] ; then
                mv ~/.xscreensaver ~/.xscreensaver.before.picasa
            fi
        fi

        mv ~/.xscreensaver.picasa ~/.xscreensaver

    fi



    # Then put the picasascr.desktop file into ~/.kde/...
    mkdir -p ~/.kde/share/applnk/System/ScreenSavers/
    if [ -h ~/.kde/share/applnk/System/ScreenSavers/picasascr.desktop ] ; then
        rm -f ~/.kde/share/applnk/System/ScreenSavers/picasascr.desktop 
    fi
    ln -s $PIC_ROOT/desktop/picasascr.desktop ~/.kde/share/applnk/System/ScreenSavers/

    # Then set the default KDE screen saver
    if [ -f ~/.kde/share/config/kdesktoprc ] ; then
        grep -qi picasa ~/.kde/share/config/kdesktoprc
        if [ $? -eq 0 ] ; then
            append_desktoprc=false
            sed 's/^Saver=.*$/Saver=picasascr.desktop/' <~/.kde/share/config/kdesktoprc >~/.kde/share/config/kdesktoprc.picasa

            if [ ! -f ~/.kde/share/config/kdesktoprc.before.picasa ] ; then
                mv ~/.kde/share/config/kdesktoprc ~/.kde/share/config/kdesktoprc.before.picasa
            fi
            mv ~/.kde/share/config/kdesktoprc.picasa ~/.kde/share/config/kdesktoprc
            
        else
            append_desktoprc=true
        fi
    else
        mkdir -p ~/.kde/share/config 
        append_desktoprc=true
    fi

    if [ x$append_desktoprc = xtrue ] ; then
        echo "[ScreenSaver]" >> ~/.kde/share/config/kdesktoprc
        echo "Saver=picasascr.desktop" >> ~/.kde/share/config/kdesktoprc
    fi

    # Then invoke their screen saver configuration utility
    ps -o cmd -U $EUID | grep -v grep | grep -q xscreensaver
    if [ $? -eq 0 ] ; then
        xscreensaver-demo &
    fi

    if [ -n "$KDE_FULL_SESSION" -o "$GDMSESSION" = "KDE" ] ; then
        kcmshell screensaver &
    fi

    return 0
}


#########
#   Override automatic computation of the Picasa root
#########
export PIC_ROOT="$SETUP_INSTALLPATH"
export PIC_BINDIR="$PIC_ROOT/bin"

#########
#   Determine if we're running as root or not
#########
rootmode=""
if [ -n "$EUID" ] ; then
    if [ $EUID -eq 0 ] ; then
        rootmode="--root"
    fi
fi


#########
#   Remove icons from the desktop + menu
#########
echo $SETUP_OPTIONTAGS | grep -q icons
if [ $? -eq 0 ] ; then
    icons $rootmode --delete google-picasa.desktop
fi

#########
#   Remove any screen savers done
#########
if [ -n "$EUID" ] ; then
    if [ $EUID -eq 0 ] ; then
        setpicasascreensaver remove
    fi
fi
echo $SETUP_OPTIONTAGS | grep -q package
if [ $? -ne 0 ] ; then
    setpicasascreensaver unset
fi

#########
#   Remove the symlink in /usr/bin if we're installing as root
#########
if [ $EUID -eq 0 ] ; then
    if [ -h /usr/bin/picasa ] ; then
        rm -f /usr/bin/picasa
    fi
fi

#########
#   For Loki based installs, remove ~/.picasa
#########
echo $SETUP_OPTIONTAGS | grep -q package
if [ $? -ne 0 ] ; then
    rm -rf ~/.picasa
fi
